#!/bin/sh

check_bug_url() {
	local BUG="$1"
	local rc=0
	local RESPONSE
	local URL="https://bugzilla.redhat.com/xmlrpc.cgi"
	local data="<?xml version='1.0' encoding='UTF-8'?><methodCall><methodName>Bug.get</methodName> <params><param><value><struct><member><name>ids</name><value>${BUG}</value></member></struct></value></param> </params> </methodCall>"
	RESPONSE="$(curl --fail --silent "${URL}" -H "Content-Type: text/xml" -d "${data}")"
	if [ $? != 0 ]; then
		echo "WARNING: Cannot reach '${URL}'"
		rc=1
	else
		RESULT="$(echo "${RESPONSE}" | \
			xmllint --xpath "/methodResponse/fault/value/struct/member/name[contains(text(), "faultCode")]/../value/int/text()" - 2> /dev/null)"

		if [ "${RESULT}" = "102" ]; then
			echo "private"
			rc=1
		elif [ "${RESULT}" = "101" ]; then
			echo "invalid"
			rc=1
		fi
	fi

	return $rc
}

COMMIT="$1"

ERROR=""
cat "${COMMIT}" | grep -o "#[0-9]*" | sed 's/#//' | sort | uniq | while read BUG; do
	if ! echo " ${BUG_FALSE} " | grep " ${BUG} " > /dev/null; then
		echo "INFO: Testing if bug '${BUG}' is private..."
		STATUS="$(check_bug_url "${BUG}")"
		if [ $? != 0 ]; then
			ERROR=1
			echo "ERROR: Bug '${BUG}' is ${STATUS}"
		fi
	fi
	[ -z "${ERROR}" ]
done || ERROR=1

cat "${COMMIT}" | grep 'Bug-Url:' | sed 's/.*Bug-Url:[ \t]*\([^ \t]*\).*/\1/' | while read URL; do
	BUG=$(echo $URL | sed -ne 's;.*?id=\([0-9]*\);\1;p' -ne 's;.*/\([0-9]*\)$;\1;p')
	echo "INFO: Testing if bug '${BUG}' is private..."
	STATUS="$(check_bug_url "${BUG}")"
	if [ $? != 0 ]; then
		ERROR=1
		echo "ERROR: Bug '${URL}' is ${STATUS}"
	fi
	[ -z "${ERROR}" ]
done || ERROR=1

[ -z "${ERROR}" ] || echo "ERROR: Private bugs validation FAILED"
exit 0 # do not fail commit
